import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import ReactDropdown from 'react-dropdown';
import { useUsMap } from './useUsMap';
import { useData } from './useData';
import { Marks } from './Marks';
import { ColorLegend } from './ColorLegend';
import { Dropdown } from './Dropdown';

import {
  csv,
  scaleSqrt,
  scaleOrdinal,
  max,
  format,
  extent,
  scaleLinear
} from 'd3';

const width = 960;
const height = 500;
const margin = { top: 20, right: 250, bottom: 65, left: 90 };
const xAxisLabelOffset = 45;
const yAxisLabelOffset = 20;
const fadeOpacity = 0.2;
const circleRadius = 6;
const legendOffset = 185;

const attributes = [
  { value: '2011', label: '2011' },
  { value: '2012', label: '2012' },
  { value: '2013', label: '2013' },
  { value: '2014', label: '2014' },
  { value: '2015', label: '2015' },
  { value: '2016', label: '2016' }
];
const getLabel = value => {
  for (let i = 0; i < attributes.length; i++) {
    if (attributes[i].value === value) {
      return attributes[i].label;
    }
  }
};


const App = () => {

  const usMap = useUsMap();
  let cities = useData();

  const [hoveredValue, setHoveredValue] = useState(null);
  
  const initialttribute = 'YEAR';
  const [Attribute, setAttribute] = useState(initialAttribute);
  const Value = d => d[Attribute];
  const Label = getLabel(Attribute);
  
  if (!usMap || !cities) {
    return <pre>Loading...</pre>;
  }

  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;

  const xValue = d => d.Longitude;
  const yValue = d => d.Latitude;

  const colorValue = d => d.CASE_STATUS;
  const colorLegendLabel = 'CASE_STATUS';
  const colorScale = scaleOrdinal()
    .domain(cities.map(colorValue))
    .range(['#a6cee3', '#e31a1c', '#fdbf6f', '#fb9a99']);

  const filteredData = cities.filter(d => hoveredValue === colorValue(d));

  const xScale = scaleLinear()
    .domain(extent(cities, xValue))
    .range([0, innerWidth])
    .nice();

  const yScale = scaleLinear()
    .domain(extent(cities, yValue))
    .range([0, innerHeight]);

  return (
	      <>
        <div className="menus-container">
        <span className="dropdown-label">X</span>
        <ReactDropdown
          options={attributes}
          value={Attribute}
          onChange={({ value }) => setXAttribute(value)}
        />
              </div>
      <svg width={width} height={height}>
        <g transform={`translate(${innerWidth + legendOffset}, 60)`}>
          <text
            x={xAxisLabelOffset}
            y={-yAxisLabelOffset}
            className="axis-label"
            textAnchor="middle"
          >
            {colorLegendLabel}
          </text>
          <ColorLegend
            tickSpacing={22}
            tickSize={10}
            tickTextOffset={12}
            tickSize={circleRadius}
            colorScale={colorScale}
            onHover={setHoveredValue}
            hoveredValue={hoveredValue}
            fadeOpacity={fadeOpacity}
          />
        </g>

        <g transform={`translate(-70, 0)`}>
          <g opacity={hoveredValue ? fadeOpacity : 1}>
            <Marks
              usMap={usMap}
              cities={cities}
              colorScale={colorScale}
              colorValue={colorValue}
            />
          </g>
          <Marks
            usMap={usMap}
            cities={filteredData}
            colorScale={colorScale}
            colorValue={colorValue}
          />
        </g>
      </svg>
      </>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
